# octo-deco
This tool comes with all the usual warnings, and all of the usual "no guarantee"s. I've found it fun to write, I've found it's a useful tool to help me understand decompression theory, and I would use it as a tool to plan decompression dives. I would always check decompression profiles against tables or another tool.

TL;DR:
> **Don't put your life in the hands of some idiot on the internet.**

# Features
* Decompression computations using Bühlmann ZHL-16C with Gradient Factors,
  directly usable as a Python library 
* Tightly integrated with web app allowing creation, deletion and manipulation
  of dive profiles
* Insightful plots, not just of the dive itself, but also eg. heat maps of tissue loading
* Gas consumption computations, including lost-gas scenarios
* Import dives from Shearwater computers (through CSV) 
* Analysis of options for decompression profiles from gradient factors

TODO finish
  
A version of the library is available directly from [octo-deco.nl](https://octo-deco.nl).

# Contact info
[Dan Roozemond](mailto:dan.roozemond@gmail.com)
 
# License
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

# Installing
See `install.md`.


